"""Grid Infrastructure Test

Retrieves information about the infrastructure of the grid. (site name, ce name,
batch system, queue)

Author: Thomas Low <thomas.low@cern.ch>

Changelog:
* Fri Nov 21 2008 Thomas Low <thomas.low@cernc.h> v1.1.1
- Bugfix splitting of CE-string to get batch system/queue.
* Fri Nov 21 2008 Thomas Low <thomas.low@cern.ch> v1.1
- Rename arguments according to to GLUE specification
- Get batch system and queue from CE-string before manually querying environment
  variables.
"""

import sys, os
from gcm.common.test import Test

def getSiteName():
	return os.environ.get("SITE_NAME")
	
def getCeName():
	n = os.environ.get("GLITE_CE")
	if not n:
		n = os.environ.get("GLOBUS_CE")
	return n
	
def getBatchSystem(ce):
	if ce:
		slash = ce.split("/")
		if len(slash) > 1: 
			minus = slash[-1].split("-")
			if len(minus) > 2:
				return (minus[-2], minus[-1])
	if os.environ.has_key("PBS_QUEUE"):
		return ("PBS",os.environ.get("PBS_QUEUE"))
	elif os.environ.has_key("LSB_QUEUE"):
		return ("LSF",os.environ.get("LSB_QUEUE"))
	elif os.environ.has_key("SGE_CELL") and os.environ.has_key("QUEUE"):
		return ("SGE",os.environ.get("QUEUE"))
	return (None, None)

def getTest():
	t = Test("grid_infra")
	t.testVersion = "1.1.1"
	t.pyamqEncrypt = "1"
	data = []

	site = getSiteName()
	if site:
		t.GlueSiteUniqueID = site
	else:
		data.append("GlueSiteUniqueID could not be gathered")
	
	ce = getCeName()
	if ce:
		t.GlueCEUniqueID = ce
	else:
		data.append("GlueCEUniqueID could not be gathered")
		
	bs, q = getBatchSystem(ce)
	if bs:
		t.batchSystem = bs
		t.summary = bs[:6]
	else:
		data.append("batchSystem could not be gathered")
		
	if q:
		t.batchQueue = q
	else:
		data.append("batchQueue could not be gathered")
	
	if data:
		t.data = "\n".join(data)
		
	return t
	

